% Demo script
% Demonstrates how to convert from ARTS to nc-format, write netCDF files,
% and read the netCDF files
%
%%
data_folder = '/home/robin/temp/ellipsoid_1.0_2.0_0-0-0';   % Location of .mat-files
save_folder = './temp'; % Where to save the netCDF data

%% Find .mat-files
folders = dir(data_folder);
data_read = [];
for folder=folders'
    if any(strcmp(folder.name, {'.' '..'}));
        continue
    end
    folder_path = fullfile(data_folder, folder.name);
    temp = textscan(folder.name, 'beta%f');
    tilt_angle = temp{1};
    files = dir(folder_path);
    for file = files'
       file_path = fullfile(folder_path, file.name);
       [p, f, ext] = fileparts(file_path);
       if strcmp(ext, '.mat')
           clear miscData log_Data data_arts
            %% Load .mat-file
            data_arts = load(file_path); 
            data_arts.ssdm.mass =...
                917*pi/6*data_arts.ssdm.diameter_volume_equ^3;
            %% Conversion to the nc-format
            misc_Data.habit_name = 'ellipsoid';
            misc_Data.habit_id = nan;
            misc_Data.phase = 'ice';
            misc_Data.refrIndex_homogenous_bool = true;
            misc_Data.density_homogenous_bool = true;
            misc_Data.dpl = nan;
            misc_Data.N_dp = nan;
            misc_Data.refrIndex = nan;
            misc_Data.shape_file = '';
            misc_Data.beta = tilt_angle;
            misc_Data.alpha = 0;
            misc_Data.gamma = 0;

            log_Data.software_version = '';
            log_Data.system = '';
            log_Data.N_nodes = nan;
            log_Data.N_cores = nan;
            log_Data.date = '';
            log_Data.eps = '';
            log_Data.ADDA_avgParam_file = '';
            log_Data.ADDA_scatParam_file = '';
            data_nc = ssdb_convertArtsToNc(data_arts.ssd, data_arts.ssdm, misc_Data, log_Data);            
            
            %% Define save path
            habit_param = [];
            habit_param.name = 'ellipsoid';
            habit_param.id = 123;
            habit_param.phase = 'ice';
            habit_param.macro_type = 'aggregate';
            habit_param.micro_type = 'pristine';
            habit_param.refrIndex_homogenous_bool = true;
            habit_param.density_homogenous_bool = true;
            habit_param.source = 'something';
            habit_param.description = 'descriptive here';
            habit_param.title_name = 'The ellipsoid';
            habit_param.comment = 'Optional commentary';
            habit_param.refrIndex_model = 'Matzler 2000';
            % Shoud use ssdb_habitSpec to create habit_param, when writting in the database itself
            
            orient_type = data_nc.SingleScatteringData.orient_type;
            fileStruct_def = ssdb_fileStructDef(habit_param, save_folder, orient_type);
            
            param = data_nc.SingleScatteringData;
            param.diameter_max = data_nc.ShapeData.diameter_max;
            param.diameter_vol_eq = data_nc.ShapeData.diameter_vol_eq;
            param.mass = data_nc.ShapeData.mass;
            param.beta = data_nc.ShapeData.beta;
            
            nc_file = ssdb_getFilePath(fileStruct_def.ssd_path.nc_file, param);
            nc_folder = ssdb_getFilePath(fileStruct_def.ssd_path.bottom_folder, param);
            if exist(nc_folder, 'dir') ~= 7
                mkdir(nc_folder);
            end
            %% write data to nc file
            if exist(nc_file, 'file') == 2
                delete(nc_file)
            end
            clear ssdb_write_ncfile % remove persitent variable
            ssdb_write_ncfile(nc_file, data_nc)
            
            %% Read nc file
            if isempty(data_read)
                data_read = ssdb_read_ncfile(nc_file);
            else
                data_read(end+1) = ssdb_read_ncfile(nc_file);   
            end
       end
    end
end



