% RUN_SCATDATA_CHECK  Checks a S-array using ARTS' scat_dataCheck
%
%    You need Atmlab, and then configured with ARTS, to run this function.
%
% FORMAT  all_ok = run_scatdata_check( S, verbose )
%
% OUT all_ok   Boorlean, true if all OK.
% IN  S        Data to check, as a Matlab struct vector (S(1) ...)
%     verbose  If set to false, all_ok is returned without any message. 
%              If set to true, as above if no problem, but a full error
%              is given if any problem detected.

% 2017-12-01, Pattrick Eriksson

function all_ok = run_scatdata_check( S, verbose )


%- Create workfolder?
%
workfolder = create_tmpfolder;
cu = onCleanup( @()delete_tmpfolder( workfolder ) );


%- Save S and M to workfolder
%
sfile = fullfile( workfolder, 's.xml' );
%
for k = 1 : length(S)
  Sx{1}{k} = S(k);
end
%
xmlStore( sfile, Sx, 'ArrayOfArrayOfSingleScatteringData', 'binary' );
%
clear Sx


%- Create cfile
%
T     = create_cfile_local( sfile );
cfile = fullfile( workfolder, 'cfile.arts' );
%
strs2file( cfile, T );


%- Run ARTS
%
status = arts( cfile, ~verbose );
%
all_ok = ~status;

return



function T = create_cfile_local( sfile )
  T{1}     = 'Arts2{';
  T{end+1} = sprintf( 'ReadXML( scat_data, "%s" )', sfile );  
  T{end+1} = 'scat_dataCheck';  
  T{end+1} = '}';
return
